@@ -4,11 +4,11 @@ use strict;
 use warnings;
 
 use Mo qw(build is);
-use Mo::utils qw(check_isa check_length check_required);
+use Mo::utils qw(check_isa check_length check_number check_required);
 
 extends 'Data::Image';
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 has commons_name => (
 	is => 'ro',
@@ -22,9 +22,13 @@ has dt_uploaded => (
 	is => 'ro',
 );
 
-has license => {
+has license => (
 	is => 'ro',
-};
+);
+
+has page_id => (
+	is => 'ro',
+);
 
 sub BUILD {
 	my $self = shift;
@@ -39,6 +43,9 @@ sub BUILD {
 	# Check date uploaded.
 	check_isa($self, 'dt_uploaded', 'DateTime');
 
+	# Check page_id.
+	check_number($self, 'page_id');
+
 	return;
 }
 
@@ -67,6 +74,7 @@ Data::Commons::Image - Data object for Wikimedia Commons image.
  my $height = $obj->height;
  my $id = $obj->id;
  my $license = $obj->license;
+ my $page_id = $obj->page_id;
  my $size = $obj->size;
  my $url = $obj->url;
  my $url_cb = $obj->url_cb;
@@ -135,6 +143,13 @@ Image license.
 It's optional.
 Default value is undef.
 
+=item * C<page_id>
+
+Image page id on Wikimedia Commons.
+It's used for structured data with 'M' prefix.
+It's optional.
+Default value is undef.
+
 =item * C<size>
 
 Image size.
@@ -225,6 +240,14 @@ Get image license.
 
 Returns string.
 
+=head2 C<page_id>
+
+ my $page_id = $obj->page_id;
+
+Get image page id.
+
+Returns number.
+
 =head2 C<size>
 
  my $size = $obj->size;
@@ -283,6 +306,7 @@ Returns number.
          ),
          'height' => 2730,
          'license' => 'cc-by-sa-4.0',
+         'page_id' => '95648152',
          'size' => 1040304,
          'url' => 'https://upload.wikimedia.org/wikipedia/commons/a/a4/Michal_from_Czechia.jpg',
          'width' => 4096,
@@ -297,6 +321,7 @@ Returns number.
  print 'URL: '.$obj->url."\n";
  print 'Width: '.$obj->width."\n";
  print 'License: '.$obj->license."\n";
+ print 'Page id: '.$obj->page_id."\n";
  print 'Date and time the photo was created: '.$obj->dt_created."\n";
  print 'Date and time the photo was uploaded: '.$obj->dt_uploaded."\n";
 
@@ -309,6 +334,7 @@ Returns number.
  # URL: https://upload.wikimedia.org/wikipedia/commons/a/a4/Michal_from_Czechia.jpg
  # Width: 4096
  # License: cc-by-sa-4.0
+ # Page id: 95648152
  # Date and time the photo was created: 2022-01-01T00:00:00
  # Date and time the photo was uploaded: 2022-07-14T00:00:00
 
@@ -336,6 +362,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
